"""Implementation of XBAspecies class.

Peter Schubert, HHU Duesseldorf, May 2022
"""

import sbmlxdf


class XbaSpecies:

    def __init__(self, s_species):
        self.id = s_species.name
        self.name = s_species.get('name', '')
        self.sboterm = s_species['sboterm']
        self.compartment = s_species['compartment']
        self.initial_conc = s_species['initialConcentration']
        self.constant = s_species['constant']
        self.boundary = s_species['boundaryCondition']
        self.units = s_species['substanceUnits']
        attrs = sbmlxdf.misc.extract_xml_attrs(s_species['xmlAnnotation'], token='molecule')
        self.mw = float(attrs['weight_Da'])
        self.ps_rid = None
        self.m_reactions = {}
        self.ps_reactions = {}
        self.p_degrad_rids = {}
        self.p_trans_rids = {}

    def set_ps_rid(self, rid):
        self.ps_rid = rid

    def add_m_reaction(self, rid, stoic):
        self.m_reactions[rid] = stoic

    def add_ps_reaction(self, rid, stoic):
        self.ps_reactions[rid] = stoic

    def add_p_degrad_rid(self, rid, stoic):
        self.p_degrad_rids[rid] = stoic

    def add_p_transition_rid(self, rid, stoic):
        self.p_trans_rids[rid] = stoic
